from enum import Enum


class FlowModuleValue2Type5BranchesItemModulesItemSleepType0Type(str, Enum):
    STATIC = "static"

    def __str__(self) -> str:
        return str(self.value)
